{% extends "base.html" %}
{% block content %}
<div class="row">
  <div class="s12">
    <div class="card">
      <div class="card-content">
        <span class="card-title red-text space-below">Page Not Found</span>
        <p class="space-below">Error 404 - This page was not found</p>
      </div>
      <div class="card-action">
        <a href="/">Back</a>
      </div>
    </div>
  </div>
</div>
{% endblock %}