<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>PicoBrew Server</title>

  <link rel="apple-touch-icon" sizes="72x72" href="/static/img/apple-icon-72x72.png">
  <link rel="apple-touch-icon" sizes="114x114" href="/static/img/apple-icon-114x114.png">
  <link rel="icon" type="image/png" sizes="192x192"  href="/static/img/android-icon-192x192.png">
  <link rel="icon" type="image/png" sizes="32x32" href="/static/img/favicon-32x32.png">
  <link rel="icon" type="image/png" sizes="96x96" href="/static/img/favicon-96x96.png">
  <link rel="icon" type="image/png" sizes="16x16" href="/static/img/favicon-16x16.png">
  <meta name="theme-color" content="#014fa2">

  <link type="text/css" rel="stylesheet" href="static/css/materialize.min.css"  media="screen,projection"/>
  <link type="text/css" rel="stylesheet" href="static/css/main.css"  media="screen,projection"/>

  <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
</head>
<body class="grey lighten-4">
  {% include "navbar.html" %}
  <div class="content container">
    <section class="section">
      {% block content %}{% endblock %}
    </section>
  </div>
  <script type="text/javascript" src="static/js/materialize.min.js"></script>
  <script type="text/javascript">
    M.AutoInit();

    {% with messages = get_flashed_messages() %}
      {% if messages %}
        {% for message in messages %}
          M.toast({html: "{{ message }}", displayLength: 60000*60, classes: "red-text" })
        {% endfor %}
      {% endif %}
    {% endwith %}
  </script>
</body>
</html>
