<div class="row">
    <div class="col s12">
        <div class="card-panel">

            <form action="/upload" method="POST" enctype="multipart/form-data">
                <div class="file-field input-field">
                    <div class="btn">
                        <span>File</span>
                        <input type="file" multiple accept=".xml,.beerxml" name="recipes"/>
                    </div>
                    <div class="file-path-wrapper">
                        <input class="file-path validate" type="text"
                               placeholder="Upload one or more BeerXML recipes."/>
                    </div>
                </div>
                <button class="btn waves-effect waves-light" type="submit" name="action">Submit
                    <i class="material-icons right">send</i>
                </button>
            </form>

        </div>
    </div>
</div>
