@font-face {
    font-family: 'Material Icons';
    font-style: normal;
    font-weight: 400;
    src: local('Material Icons'), local('MaterialIcons-Regular'), url(https://fonts.gstatic.com/s/materialicons/v7/2fcrYFNaTjcS6g4U3t-Y5UEw0lE80llgEseQY3FEmqw.woff2) format('woff2');
}

.material-icons {
    font-family: 'Material Icons';
    font-weight: normal;
    font-style: normal;
    font-size: 24px;
    line-height: 1;
    letter-spacing: normal;
    text-transform: none;
    display: inline-block;
    word-wrap: normal;
    -webkit-font-feature-settings: 'liga';
    -webkit-font-smoothing: antialiased;
}

nav {
    padding: 0 20px;
}

.card-action .collapsible, .card-action .collapsible-header, .card-action .collapsible-body {
    border: none;
    box-shadow: none;
    background-color: transparent;
    color: white;
    margin: 0;
    padding-left: 0px;
}

.card-content ul {
    margin-top: 0;
}

.card-header {
    border-bottom: 1px solid rgba(160, 160, 160, 0.2);
    text-overflow: ellipsis;
    padding: 20px;
    white-space: nowrap;
    overflow: hidden;
}

.svg-icon {
    width: 30px;
    fill: white;
}

.svg-icon svg {
    fill: white;
}

li.hop:before, li.grain:before, li.glass:before {
    content: '';
    display: inline-block;
    height: 25px;
    width: 25px;
    background-position: 0px 7px;
    background-repeat: no-repeat;
}

li.hop:before {
    background-image: url("/static/img/hop.svg");
}

li.grain:before {
    background-image: url("/static/img/grain.svg");
}

li.glass:before {
    background-image: url("/static/img/glass.svg");
}

.recipe-dashboard > div {
    margin-bottom: 10px;
    width: 100%;
    break-inside: avoid-column;
    margin-top: 0px;
    margin-bottom: 2rem;
}

@media screen and (min-width: 992px) {
    .recipe-dashboard {
        -moz-column-count: 2;
        -webkit-column-count: 2;
        column-count: 2;

        -webkit-column-gap: 10px;
        -moz-column-gap: 10px;
        column-gap: 2rem;
    }
}

.brand-logo img {
    width: 48px;
    height: 48px;
    vertical-align: middle;
}

ul ol li {
    list-style: decimal;
}

.space-below {
    margin-bottom: 40px!important;
}

.section {
    padding-top: 2rem;
    padding-bottom: 2rem;
}